heamy.estimator module
======================================

.. automodule:: heamy.estimator

Regressor
--------------

.. autoclass:: Regressor
    :members:
    :show-inheritance:
    :inherited-members:

Classifier
--------------

.. autoclass:: Classifier
    :members:
    :show-inheritance:
    :inherited-members:
